@@ -17,12 +17,6 @@ class HumanResources_Config extends Tinebase_Config_Abstract
 {
     const APP_NAME = 'HumanResources';
 
-    /**
-     * FreeTime Type
-     * @var string
-     */
-    const FREETIME_TYPE = 'freetimeType';
-
     /**
      * Vacation Status
      * @var string
@@ -62,6 +56,13 @@ class HumanResources_Config extends Tinebase_Config_Abstract
      */
     const FEATURE_CALCULATE_DAILY_REPORTS = 'calculateDailyRepots';
 
+    /**
+     * enable working time tracking
+     *
+     * @string
+     */
+    const FEATURE_STREAMS = 'featureStreams';
+
     /**
      * enable working time tracking
      *
@@ -96,22 +97,6 @@ class HumanResources_Config extends Tinebase_Config_Abstract
      * @see tine20/Tinebase/Config/Definition::$_properties
      */
     protected static $_properties = array(
-        self::FREETIME_TYPE => array(
-            //_('Freetime Type')
-            'label'                 => 'Freetime Type',
-            //_('Possible free time definitions')
-            'description'           => 'Possible free time definitions',
-            'type'                  => 'keyFieldConfig',
-            'options'               => array('recordModel' => 'HumanResources_Model_FreeTimeType'),
-            'clientRegistryInclude' => TRUE,
-            'default'               => array(
-                'records' => array(
-                    array('id' => 'SICKNESS',             'value' => 'Sickness',           'icon' => 'images/icon-set/icon_sick.svg',  'system' => TRUE),  //_('Sickness')
-                    array('id' => 'VACATION',             'value' => 'Vacation',           'icon' => 'images/icon-set/icon_vacation.svg', 'system' => TRUE),  //_('Vacation')
-                ),
-                'default' => 'VACATION'
-            )
-        ),
         self::VACATION_STATUS => array(
             //_('Vacation Status')
             'label'                 => 'Vacation Status',
@@ -174,6 +159,14 @@ class HumanResources_Config extends Tinebase_Config_Abstract
                     self::TYPE                  => self::TYPE_BOOL,
                     self::DEFAULT_STR           => true,
                 ],
+                self::FEATURE_STREAMS => [
+                    self::LABEL                 => 'Enable Streams',
+                    //_('Enable Streams')
+                    self::DESCRIPTION           => 'Activate working streams',
+                    //_('Activate working streams')
+                    self::TYPE                  => self::TYPE_BOOL,
+                    self::DEFAULT_STR           => false,
+                ],
                 self::FEATURE_WORKING_TIME_ACCOUNTING => [
                     self::LABEL                 => 'Enable Working Time Tracking',
                     //_('Enable Working Time Tracking')
@@ -182,7 +175,6 @@ class HumanResources_Config extends Tinebase_Config_Abstract
                     self::TYPE                  => self::TYPE_BOOL,
                     self::DEFAULT_STR           => false,
                 ],
-
             ],
             self::DEFAULT_STR => [],
         ],
