@@ -73,26 +73,63 @@ class HumanResources_Frontend_Json extends Tinebase_Frontend_Json_Abstract
             $this->_configuredModels = array_diff($this->_configuredModels, [
                 HumanResources_Model_BLDailyWTReport_BreakTimeConfig::MODEL_NAME_PART,
                 HumanResources_Model_BLDailyWTReport_LimitWorkingTimeConfig::MODEL_NAME_PART,
-                HumanResources_Model_FreeTimeType::MODEL_NAME_PART,
                 HumanResources_Model_BLDailyWTReport_WorkingTime::MODEL_NAME_PART,
                 HumanResources_Model_DailyWTReport::MODEL_NAME_PART,
                 HumanResources_Model_MonthlyWTReport::MODEL_NAME_PART,
                 HumanResources_Model_WageType::MODEL_NAME_PART,
             ]);
         }
+        if (! HumanResources_Config::getInstance()->featureEnabled(
+            HumanResources_Config::FEATURE_STREAMS)
+        ) {
+            $this->_configuredModels = array_diff($this->_configuredModels, [
+                HumanResources_Model_Stream::MODEL_NAME_PART,
+                HumanResources_Model_StreamModality::MODEL_NAME_PART,
+                HumanResources_Model_StreamModalReport::MODEL_NAME_PART,
+            ]);
+        }
     }
 
+    /**
+     * @param $filter
+     * @param $paging
+     * @return array
+     */
     public function searchStreams($filter, $paging)
     {
         return $this->_search($filter, $paging, HumanResources_Controller_Stream::getInstance(),
             HumanResources_Model_Stream::class);
     }
 
-    public function saveStream($data)
+    /**
+     * Return a single stream
+     *
+     * @param   string $id
+     * @return  array stream data
+     */
+    public function getStream($id)
     {
-        return $this->_save($data, HumanResources_Controller_Stream::getInstance(), HumanResources_Model_Stream::class);
+        return $this->_get($id, HumanResources_Controller_Stream::getInstance());
     }
 
+    /**
+     * creates/updates a stream
+     *
+     * @param  array $recordData
+     * @return array created/updated stream
+     */
+    public function saveStream($recordData)
+    {
+        return $this->_save($recordData, HumanResources_Controller_Stream::getInstance(), HumanResources_Model_Stream::class);
+    }
+
+    /**
+     * @param $streamId
+     * @return array
+     * @throws Tinebase_Exception_AccessDenied
+     * @throws Tinebase_Exception_InvalidArgument
+     * @throws Tinebase_Exception_NotFound
+     */
     public function generateStreamReport($streamId)
     {
         $stremCtrl = HumanResources_Controller_Stream::getInstance();
@@ -114,6 +151,11 @@ class HumanResources_Frontend_Json extends Tinebase_Frontend_Json_Abstract
         return $this->_recordToJson($stremCtrl->get($streamId));
     }
 
+    /**
+     * @param $data
+     * @return array
+     * @throws Tinebase_Exception_Record_NotAllowed
+     */
     public function saveMonthlyWTReport($data)
     {
         if (!isset($data['id']) || empty($data['id'])) {
@@ -229,43 +271,6 @@ class HumanResources_Frontend_Json extends Tinebase_Frontend_Json_Abstract
             }
         }
         
-        $aids = array();
-        $fids = array();
-        
-        // TODO: resolve this in controller
-        foreach(array('vacation', 'sickness') as $type) {
-            if (! empty($employee[$type]) && is_array($employee[$type])) {
-                foreach($employee[$type] as $v) {
-                    $aids[] = $v['account_id'];
-                    $fids[] = $v['id'];
-                }
-            }
-        }
-        
-        $aids = array_unique($aids);
-        $fids = array_unique($fids);
-        $acs = HumanResources_Controller_Account::getInstance()->getMultiple($aids);
-        $freedayFilter = new HumanResources_Model_FreeDayFilter(array());
-        $freedayFilter->addFilter(new Tinebase_Model_Filter_Text(array('field' => 'freetime_id', 'operator' => 'in', 'value' => $fids)));
-        $fds = HumanResources_Controller_FreeDay::getInstance()->search($freedayFilter);
-        $fds->setTimezone(Tinebase_Core::getUserTimezone());
-        
-        foreach(array('vacation', 'sickness') as $type) {
-            if (! empty($employee[$type]) && is_array($employee[$type])) {
-                for ($i = 0; $i < count($employee[$type]); $i++) {
-                    
-                    $account = $acs->filter('id', $employee[$type][$i]['account_id'])->getFirstRecord();
-                    
-                    if ($account) {
-                        $employee[$type][$i]['account_id'] = $account->toArray();
-                    }
-                    
-                    $freedays = $fds->filter('freetime_id', $employee[$type][$i]['id']);
-                    $employee[$type][$i]['freedays'] = $freedays->toArray();
-                }
-            }
-        }
-        
         return $employee;
     }
 
@@ -301,37 +306,7 @@ class HumanResources_Frontend_Json extends Tinebase_Frontend_Json_Abstract
                 }
             }
         }
-        
-        foreach(array('vacation', 'sickness') as $prop) {
-            if (! empty($recordData[$prop])) {
-                for ($i = 0; $i < count($recordData[$prop]); $i++) {
-                    // add account id by year if no account id is given (sickness)
-                    if (! $recordData[$prop][$i]['account_id']) {
-                        
-                        $date = new Tinebase_DateTime($recordData[$prop][$i]['firstday_date']);
-                        $year = $date->format('Y');
-                        
-                        if (! isset($this->_cachedAccountsOnSaveEmployee[$year])) {
-                            $filter = new HumanResources_Model_AccountFilter(array(array('field' => 'year', 'operator' => 'equals', 'value' => $year)));
-                            $filter->addFilter(new Tinebase_Model_Filter_Text(array('field' => 'employee_id', 'operator' => 'equals', 'value' => $recordData['id'])));
-                            $account = HumanResources_Controller_Account::getInstance()->search($filter)->getFirstRecord();
-                            if (! $account) {
-                                throw new HumanResources_Exception_NoAccount();
-                            }
-                            $this->_cachedAccountsOnSaveEmployee[$year] = $account;
-                        } else {
-                            $account = $this->_cachedAccountsOnSaveEmployee[$year];
-                        }
-                        
-                        $recordData[$prop][$i]['account_id'] = $account->getId();
-                    }
-                    // flat account id
-                    if (is_array($recordData[$prop][$i]['account_id'])) {
-                        $recordData[$prop][$i]['account_id'] = $recordData[$prop][$i]['account_id']['id'];
-                    }
-                }
-            }
-        }
+
         // auto set dates of the first contract to dates of the employee, if none are given
         if (! empty($recordData['contracts'])) {
             
@@ -496,7 +471,10 @@ class HumanResources_Frontend_Json extends Tinebase_Frontend_Json_Abstract
      * 
      * @param string $_employeeId
      * @param integer $_year
-     * @param string $_freeTimeId
+     * @param string $_freeTimeId (filters out current freetimes, sets minDate)
+     *  NOTE: minDate/maxDate => year is used for remainingVacation calculation
+     *        remainingVacation is the sum of vacations from all contracts
+     *        of this year
      * @param string $_accountId
      */
     public function getFeastAndFreeDays($_employeeId, $_year = NULL, $_freeTimeId = NULL, $_accountId = NULL)
