@@ -143,7 +143,9 @@ class HumanResources_Model_DailyWTReport extends Tinebase_Record_Abstract
                     'appName'     => 'HumanResources',
                     'modelName'   => 'Employee',
                 ],
-                self::DISABLED              => true,
+                self::UI_CONFIG             => [
+                    self::READ_ONLY             => true,
+                ],
                 self::QUERY_FILTER          => true,
             ],
             'monthlywtreport' => [
@@ -158,7 +160,9 @@ class HumanResources_Model_DailyWTReport extends Tinebase_Record_Abstract
                     'appName'     => HumanResources_Config::APP_NAME,
                     'modelName'   => HumanResources_Model_MonthlyWTReport::MODEL_NAME_PART,
                 ],
-                self::DISABLED              => true,
+                self::UI_CONFIG             => [
+                    self::READ_ONLY             => true,
+                ],
                 self::QUERY_FILTER          => true,
             ],
             'date' => [
@@ -168,7 +172,10 @@ class HumanResources_Model_DailyWTReport extends Tinebase_Record_Abstract
                 ],
                 self::LABEL                 => 'Date', // _('Date')
                 self::TYPE                  => 'date',
-                self::DISABLED              => true,
+                self::UI_CONFIG             => [
+                    self::READ_ONLY             => true,
+                ],
+                
             ],
             // kommt aus WorkingTime, z.b. von 9-17 uhr, kann auf tagesbasis im report geändert werden, siehe correction properties
             // änderungen stoßen neuberechnung an
@@ -177,14 +184,18 @@ class HumanResources_Model_DailyWTReport extends Tinebase_Record_Abstract
                 self::LABEL                 => 'Evaluation Start Time', // _('Evaluation Start Time')
                 self::TYPE                  => 'time',
                 self::NULLABLE              => true,
-                self::DISABLED              => true,
+                self::UI_CONFIG             => [
+                    self::READ_ONLY             => true,
+                ],
             ],
             'evaluation_period_end' => [ // kommt aus WorkingTime
                 self::VALIDATORS            => [Zend_Filter_Input::ALLOW_EMPTY => true],
                 self::LABEL                 => 'Evaluation End Time', // _('Evaluation End Time')
                 self::TYPE                  => 'time',
                 self::NULLABLE              => true,
-                self::DISABLED              => true,
+                self::UI_CONFIG             => [
+                    self::READ_ONLY             => true,
+                ],
             ],
             'evaluation_period_start_correction' => [
                 self::VALIDATORS            => [Zend_Filter_Input::ALLOW_EMPTY => true],
@@ -209,7 +220,9 @@ class HumanResources_Model_DailyWTReport extends Tinebase_Record_Abstract
                 self::NULLABLE              => true,
                 self::VALIDATORS            => [Zend_Filter_Input::ALLOW_EMPTY => true],
                 self::INPUT_FILTERS         => ['Zend_Filter_Empty' => null],
-                self::DISABLED              => true,
+                self::UI_CONFIG             => [
+                    self::READ_ONLY             => true,
+                ],
             ],
             'working_time_target_correction' => [
                 self::TYPE                  => self::TYPE_INTEGER,
@@ -227,15 +240,20 @@ class HumanResources_Model_DailyWTReport extends Tinebase_Record_Abstract
                 self::LABEL                 => 'Break Time Net', // _('Break Time Net')
                 self::NULLABLE              => true,
                 self::VALIDATORS            => [Zend_Filter_Input::ALLOW_EMPTY => true],
-                self::DISABLED              => true,
+                self::UI_CONFIG             => [
+                    self::READ_ONLY             => true,
+                ],
             ],
             // WorkingTime - passiert, wenn MA zu wenig pause gemacht hat
-            'break_time_deduction' => [self::TYPE                  => self::TYPE_INTEGER,
+            'break_time_deduction' => [
+                self::TYPE                  => self::TYPE_INTEGER,
                 self::SPECIAL_TYPE          => self::SPECIAL_TYPE_DURATION_SEC,
                 self::LABEL                 => 'Break Deduction Time', // _('Break Deduction Time')
                 self::NULLABLE              => true,
                 self::VALIDATORS            => [Zend_Filter_Input::ALLOW_EMPTY => true],
-                self::DISABLED              => true,
+                self::UI_CONFIG             => [
+                    self::READ_ONLY             => true,
+                ],
             ],
             self::FLDS_WORKING_TIMES  => [
                 self::TYPE                  => self::TYPE_RECORDS,
@@ -246,7 +264,9 @@ class HumanResources_Model_DailyWTReport extends Tinebase_Record_Abstract
                     self::MODEL_NAME            => HumanResources_Model_BLDailyWTReport_WorkingTime::MODEL_NAME_PART,
                     self::STORAGE               => self::TYPE_JSON,
                 ],
-                self::DISABLED              => true,
+                self::UI_CONFIG             => [
+                    self::READ_ONLY             => true,
+                ],
             ],
             // echte arbeitszeit nach regelanwendung
             'working_time_actual' => [
@@ -256,7 +276,9 @@ class HumanResources_Model_DailyWTReport extends Tinebase_Record_Abstract
                 self::NULLABLE              => true,
                 self::VALIDATORS            => [Zend_Filter_Input::ALLOW_EMPTY => true],
                 self::INPUT_FILTERS         => ['Zend_Filter_Empty' => null],
-                self::DISABLED              => true,
+                self::UI_CONFIG             => [
+                    self::READ_ONLY             => true,
+                ],
             ],
             // manuelles feld für korrekturen ("musterschüler")
             'working_time_correction' => [
@@ -274,7 +296,9 @@ class HumanResources_Model_DailyWTReport extends Tinebase_Record_Abstract
                 self::NULLABLE              => true,
                 self::VALIDATORS            => [Zend_Filter_Input::ALLOW_EMPTY => true],
                 self::INPUT_FILTERS         => ['Zend_Filter_Empty' => null],
-                self::DISABLED              => true,
+                self::UI_CONFIG             => [
+                    self::READ_ONLY             => true,
+                ],
             ],
             // z.b. krankheit, urlaub, feiertag (bei regelarbeit leer)
             'system_remark' => [
@@ -282,7 +306,9 @@ class HumanResources_Model_DailyWTReport extends Tinebase_Record_Abstract
                 self::TYPE                  => 'string',
                 self::VALIDATORS            => [Zend_Filter_Input::ALLOW_EMPTY => true],
                 self::NULLABLE              => true,
-                self::DISABLED              => true,
+                self::UI_CONFIG             => [
+                    self::READ_ONLY             => true,
+                ],
                 self::QUERY_FILTER          => true,
             ],
             'user_remark' => [
@@ -300,7 +326,9 @@ class HumanResources_Model_DailyWTReport extends Tinebase_Record_Abstract
                 self::DEFAULT_VAL           => 0,
                 self::SHY                   => true,
                 self::COPY_OMIT             => true,
-                self::DISABLED              => true,
+                self::UI_CONFIG             => [
+                    self::READ_ONLY             => true,
+                ],
             ],
             'calculation_failure' => [
                 self::LABEL                 => 'Calculation Error', // _('Calculation Error')
@@ -347,4 +375,4 @@ class HumanResources_Model_DailyWTReport extends Tinebase_Record_Abstract
     {
         return (int)$this->working_time_target + (int)$this->working_time_target_correction;
     }
-}
\ No newline at end of file
+}
