@@ -476,7 +476,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/HumanResources'] = ({
 : "Tage der Krankmeldung"
 
 , "Working Time Correction"
-: "Arbeitszeit (Berichtigt)"
+: "Arbeitszeitkorrektur"
 
 , "Actual Working Time"
 : "Arbeitszeit (Ist)"
@@ -491,7 +491,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/HumanResources'] = ({
 : "Anmerkung"
 
 , "Is Cleared"
-: "Ist Freigegeben"
+: "Ist Abgerechnet"
 
 , "Cleared in"
 : ""
@@ -931,6 +931,21 @@ Tine.__translationData.msgs['./LC_MESSAGES/HumanResources'] = ({
 , "Work Time Limits"
 : "Arbeitzeitlimits"
 
+, "Free Time Planning"
+: "Abwesenheitsplanung"
+
+, "Add Free Time"
+: "Abwesenheit hinzufügen"
+
+, "Edit Free Time"
+: "Abwesenheit bearbeiten"
+
+, "Delete Free Time"
+: "Abwesenheit löschen"
+
+, "Freetime"
+: "Abwesenheit"
+
 , "Human Resources"
 : ""
 
