@@ -10,18 +10,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/HumanResources'] = ({
 , "You do not have admin rights on HumanResources"
 : "You do not have admin rights on HumanResources"
 
-, "Wage types"
-: "Wage types"
+, "Working time model"
+: "Working time model"
 
-, "Free time types"
-: "Free time types"
-
-, "Working time scheme, Working time schemes"
-: [
-  "Working time scheme"
- ,"Working time schemes"
-
-]
 , "Book as vacation"
 : "Book as vacation"
 
@@ -52,14 +43,14 @@ Tine.__translationData.msgs['./LC_MESSAGES/HumanResources'] = ({
  ,"Human Resources"
 
 ]
-, "Template"
-: "Template"
+, "Title"
+: "Title"
 
-, "Individual"
-: "Individual"
+, "Work Start"
+: "Work Start"
 
-, "Shared"
-: "Shared"
+, "Work End"
+: "Work End"
 
 , "Edit {0} for {1} - {2}"
 : "Edit {0} for {1} - {2}"
@@ -118,18 +109,48 @@ Tine.__translationData.msgs['./LC_MESSAGES/HumanResources'] = ({
 , "Description"
 : "Description"
 
+, "Working time Model"
+: "Working time Model"
+
+, "Work start"
+: "Work start"
+
+, "not set"
+: "not set"
+
+, "Work end"
+: "Work end"
+
+, "Working Hours per week"
+: "Working Hours per week"
+
+, "Mon."
+: "Mon."
+
+, "Tue."
+: "Tue."
+
+, "Wed."
+: "Wed."
+
+, "Thu."
+: "Thu."
+
+, "Fri."
+: "Fri."
+
+, "Sat."
+: "Sat."
+
+, "Sun."
+: "Sun."
+
 , "Employee, Employees"
 : [
   "Employee"
  ,"Employees"
 
 ]
-, "Calculate all Reports"
-: "Calculate all Reports"
-
-, "Recalculate"
-: "Recalculate"
-
 , "Cancel"
 : "Cancel"
 
@@ -148,6 +169,15 @@ Tine.__translationData.msgs['./LC_MESSAGES/HumanResources'] = ({
 , "Vacation expires"
 : "Vacation expires"
 
+, "Breaks"
+: "Breaks"
+
+, "Hours"
+: "Hours"
+
+, "Break duration"
+: "Break duration"
+
 , "Book remaining vacation"
 : "Book remaining vacation"
 
@@ -202,9 +232,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/HumanResources'] = ({
 , "Edit {0}"
 : "Edit {0}"
 
-, "Working Time Rules"
-: "Working Time Rules"
-
 , "Start Date"
 : "Start Date"
 
@@ -214,36 +241,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/HumanResources'] = ({
 , "Feast Calendar"
 : "Feast Calendar"
 
+, "Choose the template"
+: "Choose the template"
+
 , "Vacation days of one calendar year"
 : "Vacation days of one calendar year"
 
-, "Working Time Schema"
-: "Working Time Schema"
-
-, "Working Hours per week"
-: "Working Hours per week"
-
-, "Mon."
-: "Mon."
-
-, "Tue."
-: "Tue."
-
-, "Wed."
-: "Wed."
-
-, "Thu."
-: "Thu."
-
-, "Fri."
-: "Fri."
-
-, "Sat."
-: "Sat."
-
-, "Sun."
-: "Sun."
-
 , "Edit {0} \"{1}\""
 : "Edit {0} \"{1}\""
 
@@ -310,18 +313,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/HumanResources'] = ({
 , "Banking Information"
 : "Banking Information"
 
-, "Type"
-: "Type"
-
-, "Template (individual working time schemas are created for each contract)"
-: "Template (individual working time schemas are created for each contract)"
-
-, "Shared (this working time schemas can be shared among contracts)"
-: "Shared (this working time schemas can be shared among contracts)"
-
 , "Days"
 : "Days"
 
+, "Type"
+: "Type"
+
 , "Expiration date"
 : "Expiration date"
 
@@ -385,66 +382,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/HumanResources'] = ({
 , "Part-time 20 hours"
 : "Part-time 20 hours"
 
-, "Default wage type"
-: "Default wage type"
-
-, "Salary"
-: "Salary"
-
-, "Business trip"
-: "Business trip"
-
-, "Sunday bonus"
-: "Sunday bonus"
-
-, "Feast day"
-: "Feast day"
-
-, "Feast day bonus"
-: "Feast day bonus"
-
-, "Overtime"
-: "Overtime"
-
-, "Overtime bonus"
-: "Overtime bonus"
-
-, "Late shift bonus"
-: "Late shift bonus"
-
-, "Night bonus"
-: "Night bonus"
-
-, "Break"
-: "Break"
-
-, "Stand by"
-: "Stand by"
-
-, "Unpaid"
-: "Unpaid"
-
-, "[S] Sickness"
-: "[S] Sickness"
-
-, "[D] Visit doctor"
-: "[D] Visit doctor"
-
-, "[V] Vacation"
-: "[V] Vacation"
-
-, "[BT] Business trip"
-: "[BT] Business trip"
-
-, "[FT] Flex time"
-: "[FT] Flex time"
-
-, "[BK] Break"
-: "[BK] Break"
-
-, "[T] Training"
-: "[T] Training"
-
 , "Freetime Type"
 : "Freetime Type"
 
@@ -508,27 +445,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/HumanResources'] = ({
 , "Timetracker Timeaccount for Workingtime Tracking"
 : "Timetracker Timeaccount for Workingtime Tracking"
 
-, "No valid contract for this date"
-: "No valid contract for this date"
-
-, "unexpected error: "
-: "unexpected error: "
-
-, "daily wt reports can't be created"
-: "daily wt reports can't be created"
-
-, "It is not allowed to update a cleared report"
-: "It is not allowed to update a cleared report"
-
-, "monthly wt reports can't be created"
-: "monthly wt reports can't be created"
-
-, "previous months need to be cleared first"
-: "previous months need to be cleared first"
-
-, "following months need to be uncleared first"
-: "following months need to be uncleared first"
-
 , "Daily Working Time Report, Daily Working Time Reports"
 : [
   "Daily Working Time Report"
@@ -544,17 +460,14 @@ Tine.__translationData.msgs['./LC_MESSAGES/HumanResources'] = ({
 , "Evaluation End Time"
 : "Evaluation End Time"
 
-, "Corrected Evaluation Start Time"
-: "Corrected Evaluation Start Time"
+, "Paid Absence Time"
+: "Paid Absence Time"
 
-, "Corrected Evaluation End Time"
-: "Corrected Evaluation End Time"
+, "Unpaid Absence Time"
+: "Unpaid Absence Time"
 
-, "Target Working Time"
-: "Target Working Time"
-
-, "Target Working Time Correction"
-: "Target Working Time Correction"
+, "Absence"
+: "Absence"
 
 , "Break Time Net"
 : "Break Time Net"
@@ -562,17 +475,23 @@ Tine.__translationData.msgs['./LC_MESSAGES/HumanResources'] = ({
 , "Break Deduction Time"
 : "Break Deduction Time"
 
-, "Working Times"
-: "Working Times"
+, "Feast Time"
+: "Feast Time"
 
-, "Actual Working Time"
-: "Actual Working Time"
+, "Break Time"
+: "Break Time"
+
+, "Sickness Time"
+: "Sickness Time"
 
 , "Working Time Correction"
 : "Working Time Correction"
 
-, "Total Working Time"
-: "Total Working Time"
+, "Actual Working Time"
+: "Actual Working Time"
+
+, "Target Working Time"
+: "Target Working Time"
 
 , "System Remark"
 : "System Remark"
@@ -583,99 +502,21 @@ Tine.__translationData.msgs['./LC_MESSAGES/HumanResources'] = ({
 , "Is Cleared"
 : "Is Cleared"
 
-, "Calculation Error"
-: "Calculation Error"
+, "Cleared in"
+: "Cleared in"
 
-, "Monthly Working Time Report, Monthly Working Time Reports"
+, "Working time, Working times"
 : [
-  "Monthly Working Time Report"
- ,"Monthly Working Time Reports"
+  "Working time"
+ ,"Working times"
 
 ]
-, "Month"
-: "Month"
-
-, "Daily Working Time Reports"
-: "Daily Working Time Reports"
-
-, "Working Time Balance Previous Month"
-: "Working Time Balance Previous Month"
-
-, "Total Working Time Balance"
-: "Total Working Time Balance"
-
-, "Wage type, Wage types"
-: [
-  "Wage type"
- ,"Wage types"
-
-]
-, "Abbreviation"
-: "Abbreviation"
-
-, "Name"
-: "Name"
-
-, "System"
-: "System"
-
-, "Factor (%)"
-: "Factor (%)"
-
-, "Additional Wage"
-: "Additional Wage"
-
 , "Quick search"
 : "Quick search"
 
 , "Extra free times"
 : "Extra free times"
 
-, "Start time"
-: "Start time"
-
-, "Break Time, Break Times"
-: [
-  "Break Time"
- ,"Break Times"
-
-]
-, "After exceeding {{time_worked|date(\"H:i\", \"GMT\")}} of working time {{break_time|date(\"H:i\", \"GMT\")}} break time gets deducted automatically."
-: "After exceeding {{time_worked|date(\"H:i\", \"GMT\")}} of working time {{break_time|date(\"H:i\", \"GMT\")}} break time gets deducted automatically."
-
-, "Time worked"
-: "Time worked"
-
-, "Break time"
-: "Break time"
-
-, "Work Time Limit, Work Time Limits"
-: [
-  "Work Time Limit"
- ,"Work Time Limits"
-
-]
-, "Working time is evaluated from {{start_time|date(\"H:i\")}} until {{end_time|date(\"H:i\")}}."
-: "Working time is evaluated from {{start_time|date(\"H:i\")}} until {{end_time|date(\"H:i\")}}."
-
-, "Absence reason, Absence reasons"
-: [
-  "Absence reason"
- ,"Absence reasons"
-
-]
-, "Allow Booking"
-: "Allow Booking"
-
-, "Allow Planning"
-: "Allow Planning"
-
-, "Enable Freetime Timetracking"
-: "Enable Freetime Timetracking"
-
-, "Timeaccount"
-: "Timeaccount"
-
 , "Free Time, Free Times"
 : [
   "Free Time"
@@ -706,8 +547,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/HumanResources'] = ({
 , "Number"
 : "Number"
 
-, "Transponder Id"
-: "Transponder Id"
+, "Badge Id"
+: "Badge Id"
 
 , "Germany"
 : "Germany"
@@ -736,9 +577,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/HumanResources'] = ({
 , "Cell Phone Number"
 : "Cell Phone Number"
 
-, "Title"
-: "Title"
-
 , "Last Name"
 : "Last Name"
 
@@ -787,6 +625,15 @@ Tine.__translationData.msgs['./LC_MESSAGES/HumanResources'] = ({
  ,"Free Days"
 
 ]
+, "Break, Breaks"
+: [
+  "Break"
+ ,"Breaks"
+
+]
+, "Workingtime"
+: "Workingtime"
+
 , "No contract could be found."
 : "No contract could be found."
 
@@ -841,8 +688,242 @@ Tine.__translationData.msgs['./LC_MESSAGES/HumanResources'] = ({
 , "Edit birthday, account data and other private information of employee records"
 : "Edit birthday, account data and other private information of employee records"
 
-, "Working time scheme"
-: "Working time scheme"
+, "Public Holiday Calendar"
+: "Public Holiday Calendar"
+
+, "Here you can define the default public holiday calendar used to set public holidays and other free days in datepicker"
+: "Here you can define the default public holiday calendar used to set public holidays and other free days in datepicker"
+
+, "Public Holidays"
+: "Public Holidays"
+
+, "Badge ID"
+: "Badge ID"
+
+, "Quick Search"
+: "Quick Search"
+
+, "Full Name"
+: "Full Name"
+
+, "Street2"
+: "Street2"
+
+, "Wage types"
+: "Wage types"
+
+, "Free time types"
+: "Free time types"
+
+, "Working time scheme, Working time schemes"
+: [
+  "Working time scheme"
+ ,"Working time schemes"
+
+]
+, "Template"
+: "Template"
+
+, "Individual"
+: "Individual"
+
+, "Shared"
+: "Shared"
+
+, "Calculate all Reports"
+: "Calculate all Reports"
+
+, "Recalculate"
+: "Recalculate"
+
+, "Working Time Rules"
+: "Working Time Rules"
+
+, "Working Time Schema"
+: "Working Time Schema"
+
+, "Template (individual working time schemas are created for each contract)"
+: "Template (individual working time schemas are created for each contract)"
+
+, "Shared (this working time schemas can be shared among contracts)"
+: "Shared (this working time schemas can be shared among contracts)"
+
+, "Default wage type"
+: "Default wage type"
+
+, "Salary"
+: "Salary"
+
+, "Business trip"
+: "Business trip"
+
+, "Sunday bonus"
+: "Sunday bonus"
+
+, "Feast day"
+: "Feast day"
+
+, "Feast day bonus"
+: "Feast day bonus"
+
+, "Overtime"
+: "Overtime"
+
+, "Overtime bonus"
+: "Overtime bonus"
+
+, "Late shift bonus"
+: "Late shift bonus"
+
+, "Night bonus"
+: "Night bonus"
+
+, "Stand by"
+: "Stand by"
+
+, "Unpaid"
+: "Unpaid"
+
+, "[S] Sickness"
+: "[S] Sickness"
+
+, "[D] Visit doctor"
+: "[D] Visit doctor"
+
+, "[V] Vacation"
+: "[V] Vacation"
+
+, "[BT] Business trip"
+: "[BT] Business trip"
+
+, "[FT] Flex time"
+: "[FT] Flex time"
+
+, "[BK] Break"
+: "[BK] Break"
+
+, "[T] Training"
+: "[T] Training"
+
+, "No valid contract for this date"
+: "No valid contract for this date"
+
+, "unexpected error: "
+: "unexpected error: "
+
+, "daily wt reports can't be created"
+: "daily wt reports can't be created"
+
+, "It is not allowed to update a cleared report"
+: "It is not allowed to update a cleared report"
+
+, "monthly wt reports can't be created"
+: "monthly wt reports can't be created"
+
+, "previous months need to be cleared first"
+: "previous months need to be cleared first"
+
+, "following months need to be uncleared first"
+: "following months need to be uncleared first"
+
+, "Corrected Evaluation Start Time"
+: "Corrected Evaluation Start Time"
+
+, "Corrected Evaluation End Time"
+: "Corrected Evaluation End Time"
+
+, "Target Working Time Correction"
+: "Target Working Time Correction"
+
+, "Working Times"
+: "Working Times"
+
+, "Total Working Time"
+: "Total Working Time"
+
+, "Calculation Error"
+: "Calculation Error"
+
+, "Monthly Working Time Report, Monthly Working Time Reports"
+: [
+  "Monthly Working Time Report"
+ ,"Monthly Working Time Reports"
+
+]
+, "Month"
+: "Month"
+
+, "Daily Working Time Reports"
+: "Daily Working Time Reports"
+
+, "Working Time Balance Previous Month"
+: "Working Time Balance Previous Month"
+
+, "Total Working Time Balance"
+: "Total Working Time Balance"
+
+, "Wage type, Wage types"
+: [
+  "Wage type"
+ ,"Wage types"
+
+]
+, "Abbreviation"
+: "Abbreviation"
+
+, "Name"
+: "Name"
+
+, "System"
+: "System"
+
+, "Factor (%)"
+: "Factor (%)"
+
+, "Additional Wage"
+: "Additional Wage"
+
+, "Start time"
+: "Start time"
+
+, "After exceeding {{time_worked|date(\"H:i\", \"GMT\")}} of working time {{break_time|date(\"H:i\", \"GMT\")}} break time gets deducted automatically."
+: "After exceeding {{time_worked|date(\"H:i\", \"GMT\")}} of working time {{break_time|date(\"H:i\", \"GMT\")}} break time gets deducted automatically."
+
+, "Time worked"
+: "Time worked"
+
+, "Break time"
+: "Break time"
+
+, "Work Time Limit, Work Time Limits"
+: [
+  "Work Time Limit"
+ ,"Work Time Limits"
+
+]
+, "Working time is evaluated from {{start_time|date(\"H:i\")}} until {{end_time|date(\"H:i\")}}."
+: "Working time is evaluated from {{start_time|date(\"H:i\")}} until {{end_time|date(\"H:i\")}}."
+
+, "Absence reason, Absence reasons"
+: [
+  "Absence reason"
+ ,"Absence reasons"
+
+]
+, "Allow Booking"
+: "Allow Booking"
+
+, "Allow Planning"
+: "Allow Planning"
+
+, "Enable Freetime Timetracking"
+: "Enable Freetime Timetracking"
+
+, "Timeaccount"
+: "Timeaccount"
+
+, "Transponder Id"
+: "Transponder Id"
 
 , "Human Resources"
 : "Human Resources"
@@ -868,20 +949,8 @@ Tine.__translationData.msgs['./LC_MESSAGES/HumanResources'] = ({
 , "Daily Working Time Report"
 : "Daily Working Time Report"
 
-, "Monthly Working Time Report"
-: "Monthly Working Time Report"
-
-, "Wage type"
-: "Wage type"
-
-, "Break Time"
-: "Break Time"
-
-, "Work Time Limit"
-: "Work Time Limit"
-
-, "Absence reason"
-: "Absence reason"
+, "Working time"
+: "Working time"
 
 , "Free Time"
 : "Free Time"
@@ -889,6 +958,24 @@ Tine.__translationData.msgs['./LC_MESSAGES/HumanResources'] = ({
 , "Free Day"
 : "Free Day"
 
+, "Break"
+: "Break"
+
+, "Working time scheme"
+: "Working time scheme"
+
+, "Monthly Working Time Report"
+: "Monthly Working Time Report"
+
+, "Wage type"
+: "Wage type"
+
+, "Work Time Limit"
+: "Work Time Limit"
+
+, "Absence reason"
+: "Absence reason"
+
 }); 
 /********************** translation loaded flag **********************/ 
 Tine.__translationData.__isLoaded = true; 
