@@ -10,17 +10,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/HumanResources'] = ({
 , "You do not have admin rights on HumanResources"
 : "คุณไม่มีสิทธิ์ของผู้ดูแลระบบใน HumanResources"
 
-, "Wage types"
+, "Working time model"
 : ""
 
-, "Free time types"
-: ""
-
-, "Working time scheme, Working time schemes"
-: [
-  ""
-
-]
 , "Book as vacation"
 : "จองเป็นพักร้อน"
 
@@ -50,13 +42,13 @@ Tine.__translationData.msgs['./LC_MESSAGES/HumanResources'] = ({
   ""
 
 ]
-, "Template"
+, "Title"
+: "คำนำหน้าชื่อ"
+
+, "Work Start"
 : ""
 
-, "Individual"
-: ""
-
-, "Shared"
+, "Work End"
 : ""
 
 , "Edit {0} for {1} - {2}"
@@ -115,17 +107,47 @@ Tine.__translationData.msgs['./LC_MESSAGES/HumanResources'] = ({
 , "Description"
 : "การอธิบาย"
 
+, "Working time Model"
+: ""
+
+, "Work start"
+: ""
+
+, "not set"
+: ""
+
+, "Work end"
+: ""
+
+, "Working Hours per week"
+: "ชั่วโมงทำงานต่อสัปดาห์"
+
+, "Mon."
+: "จ"
+
+, "Tue."
+: "อังคาร"
+
+, "Wed."
+: "พุธ"
+
+, "Thu."
+: "พฤ."
+
+, "Fri."
+: "ศ."
+
+, "Sat."
+: "ส."
+
+, "Sun."
+: "อา."
+
 , "Employee, Employees"
 : [
   "ลูกจ้าง"
 
 ]
-, "Calculate all Reports"
-: ""
-
-, "Recalculate"
-: ""
-
 , "Cancel"
 : "ยกเลิก"
 
@@ -144,6 +166,15 @@ Tine.__translationData.msgs['./LC_MESSAGES/HumanResources'] = ({
 , "Vacation expires"
 : "พักร้อนหมด"
 
+, "Breaks"
+: ""
+
+, "Hours"
+: ""
+
+, "Break duration"
+: ""
+
 , "Book remaining vacation"
 : "จองพักร้อนที่คงค้าง"
 
@@ -195,9 +226,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/HumanResources'] = ({
 , "Edit {0}"
 : "แก้ไข {0}"
 
-, "Working Time Rules"
-: ""
-
 , "Start Date"
 : "วันที่เริ่มต้น"
 
@@ -207,36 +235,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/HumanResources'] = ({
 , "Feast Calendar"
 : "ปฏิทินงานเทศกาล"
 
+, "Choose the template"
+: "เลือกแม่แบบ ..."
+
 , "Vacation days of one calendar year"
 : "วันพักร้อนของหนึ่งปีปฏิทิน"
 
-, "Working Time Schema"
-: ""
-
-, "Working Hours per week"
-: "ชั่วโมงทำงานต่อสัปดาห์"
-
-, "Mon."
-: "จ"
-
-, "Tue."
-: "อังคาร"
-
-, "Wed."
-: "พุธ"
-
-, "Thu."
-: "พฤ."
-
-, "Fri."
-: "ศ."
-
-, "Sat."
-: "ส."
-
-, "Sun."
-: "อา."
-
 , "Edit {0} \"{1}\""
 : "แก้ไข {0} \"{1}\""
 
@@ -302,18 +306,12 @@ Tine.__translationData.msgs['./LC_MESSAGES/HumanResources'] = ({
 , "Banking Information"
 : "ข้อมูลธนาคาร"
 
-, "Type"
-: "ประเภท"
-
-, "Template (individual working time schemas are created for each contract)"
-: ""
-
-, "Shared (this working time schemas can be shared among contracts)"
-: ""
-
 , "Days"
 : "วัน"
 
+, "Type"
+: "ประเภท"
+
 , "Expiration date"
 : "หมดเขตวันที่"
 
@@ -377,66 +375,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/HumanResources'] = ({
 , "Part-time 20 hours"
 : ""
 
-, "Default wage type"
-: ""
-
-, "Salary"
-: ""
-
-, "Business trip"
-: ""
-
-, "Sunday bonus"
-: ""
-
-, "Feast day"
-: ""
-
-, "Feast day bonus"
-: ""
-
-, "Overtime"
-: ""
-
-, "Overtime bonus"
-: ""
-
-, "Late shift bonus"
-: ""
-
-, "Night bonus"
-: ""
-
-, "Break"
-: ""
-
-, "Stand by"
-: ""
-
-, "Unpaid"
-: ""
-
-, "[S] Sickness"
-: ""
-
-, "[D] Visit doctor"
-: ""
-
-, "[V] Vacation"
-: ""
-
-, "[BT] Business trip"
-: ""
-
-, "[FT] Flex time"
-: ""
-
-, "[BK] Break"
-: ""
-
-, "[T] Training"
-: ""
-
 , "Freetime Type"
 : "ประเภท เวลาว่าง"
 
@@ -500,27 +438,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/HumanResources'] = ({
 , "Timetracker Timeaccount for Workingtime Tracking"
 : ""
 
-, "No valid contract for this date"
-: ""
-
-, "unexpected error: "
-: ""
-
-, "daily wt reports can't be created"
-: ""
-
-, "It is not allowed to update a cleared report"
-: ""
-
-, "monthly wt reports can't be created"
-: ""
-
-, "previous months need to be cleared first"
-: ""
-
-, "following months need to be uncleared first"
-: ""
-
 , "Daily Working Time Report, Daily Working Time Reports"
 : [
   ""
@@ -535,16 +452,13 @@ Tine.__translationData.msgs['./LC_MESSAGES/HumanResources'] = ({
 , "Evaluation End Time"
 : ""
 
-, "Corrected Evaluation Start Time"
+, "Paid Absence Time"
 : ""
 
-, "Corrected Evaluation End Time"
+, "Unpaid Absence Time"
 : ""
 
-, "Target Working Time"
-: ""
-
-, "Target Working Time Correction"
+, "Absence"
 : ""
 
 , "Break Time Net"
@@ -553,16 +467,22 @@ Tine.__translationData.msgs['./LC_MESSAGES/HumanResources'] = ({
 , "Break Deduction Time"
 : ""
 
-, "Working Times"
+, "Feast Time"
 : ""
 
-, "Actual Working Time"
+, "Break Time"
+: ""
+
+, "Sickness Time"
 : ""
 
 , "Working Time Correction"
 : ""
 
-, "Total Working Time"
+, "Actual Working Time"
+: ""
+
+, "Target Working Time"
 : ""
 
 , "System Remark"
@@ -574,94 +494,20 @@ Tine.__translationData.msgs['./LC_MESSAGES/HumanResources'] = ({
 , "Is Cleared"
 : ""
 
-, "Calculation Error"
+, "Cleared in"
 : ""
 
-, "Monthly Working Time Report, Monthly Working Time Reports"
+, "Working time, Working times"
 : [
   ""
 
 ]
-, "Month"
-: ""
-
-, "Daily Working Time Reports"
-: ""
-
-, "Working Time Balance Previous Month"
-: ""
-
-, "Total Working Time Balance"
-: ""
-
-, "Wage type, Wage types"
-: [
-  ""
-
-]
-, "Abbreviation"
-: ""
-
-, "Name"
-: ""
-
-, "System"
-: ""
-
-, "Factor (%)"
-: ""
-
-, "Additional Wage"
-: ""
-
 , "Quick search"
 : "ค้นหาอย่างรวดเร็ว"
 
 , "Extra free times"
 : "เวลาว่างพิเศษ"
 
-, "Start time"
-: ""
-
-, "Break Time, Break Times"
-: [
-  ""
-
-]
-, "After exceeding {{time_worked|date(\"H:i\", \"GMT\")}} of working time {{break_time|date(\"H:i\", \"GMT\")}} break time gets deducted automatically."
-: ""
-
-, "Time worked"
-: ""
-
-, "Break time"
-: ""
-
-, "Work Time Limit, Work Time Limits"
-: [
-  ""
-
-]
-, "Working time is evaluated from {{start_time|date(\"H:i\")}} until {{end_time|date(\"H:i\")}}."
-: ""
-
-, "Absence reason, Absence reasons"
-: [
-  ""
-
-]
-, "Allow Booking"
-: ""
-
-, "Allow Planning"
-: ""
-
-, "Enable Freetime Timetracking"
-: ""
-
-, "Timeaccount"
-: ""
-
 , "Free Time, Free Times"
 : [
   "เวลาที่ว่าง"
@@ -691,7 +537,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/HumanResources'] = ({
 , "Number"
 : "หมายเลข"
 
-, "Transponder Id"
+, "Badge Id"
 : ""
 
 , "Germany"
@@ -721,9 +567,6 @@ Tine.__translationData.msgs['./LC_MESSAGES/HumanResources'] = ({
 , "Cell Phone Number"
 : "หมายเลขโทรศัพท์เคลื่อนที่"
 
-, "Title"
-: "คำนำหน้าชื่อ"
-
 , "Last Name"
 : "นามสกุล"
 
@@ -771,6 +614,14 @@ Tine.__translationData.msgs['./LC_MESSAGES/HumanResources'] = ({
   "วันหยุด"
 
 ]
+, "Break, Breaks"
+: [
+  ""
+
+]
+, "Workingtime"
+: "เวลาทำงาน"
+
 , "No contract could be found."
 : "ไม่พบข้อมูล"
 
@@ -825,9 +676,16 @@ Tine.__translationData.msgs['./LC_MESSAGES/HumanResources'] = ({
 , "Edit birthday, account data and other private information of employee records"
 : "แก้ไขวันเกิด ข้อมูลปัญชีและความเป็๋นส่วนตัวอื่น ๆ ของบันทึกลูกจ้าง"
 
+, "Public Holiday Calendar"
+: ""
 
+, "Here you can define the default public holiday calendar used to set public holidays and other free days in datepicker"
+: ""
 
-, "Working time scheme"
+, "Public Holidays"
+: ""
+
+, "Badge ID"
 : ""
 
 , "Human Resources"
@@ -854,19 +712,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/HumanResources'] = ({
 , "Daily Working Time Report"
 : ""
 
-, "Monthly Working Time Report"
-: ""
-
-, "Wage type"
-: ""
-
-, "Break Time"
-: ""
-
-, "Work Time Limit"
-: ""
-
-, "Absence reason"
+, "Working time"
 : ""
 
 , "Free Time"
@@ -875,6 +721,9 @@ Tine.__translationData.msgs['./LC_MESSAGES/HumanResources'] = ({
 , "Free Day"
 : "วันหยุด"
 
+, "Break"
+: ""
+
 }); 
 /********************** translation loaded flag **********************/ 
 Tine.__translationData.__isLoaded = true; 
